import { redisClient } from "syrus4-nodejs/dist/Redis.js"
// Prefix added to all the redis keys,to avoid duplicates from different instances
const prepend = process.env.APP_DATA_FOLDER || "."

/**
 *  Intended for use redis as storage wrapper in defining function
 *  could be extended in future to use diffenrent storage than redis
 */
export default {
	__client: redisClient,
	__prepend: prepend,
	set(key, value) {
		return redisClient.set(`${prepend}_${key}`, value);
	},
	get(key) {
		return redisClient.get(`${prepend}_${key}`);
	},
	remove(key) {
		return redisClient.del(`${prepend}_${key}`);
	},
	getList(key) {
		return redisClient.lrange(`${prepend}_${key}`, 0, -1);
	},
	push(key, item) {
		return redisClient.lpush(`${prepend}_${key}`, item);
	},
	unshift(key, item) {
		return redisClient.rpush(`${prepend}_${key}`, item);
	},
	pop(key) {
		return redisClient.rpop(`${prepend}_${key}`);
	},
	shift(key) {
		return redisClient.rpop(`${prepend}_${key}`);
	},
	lset(key, index, value) {
		return redisClient.lset(`${prepend}_${key}`, index, value);
	},
	slice(key, start = 0, stop) {
		return redisClient.lrange(`${prepend}_${key}`, start, stop);
	},
	trim(key, length = 500) {
		return redisClient.ltrim(`${prepend}_${key}`, 0, length);
	},
	hset(hash, key, value) {
		return redisClient.hset(`${prepend}_${hash}`, key, value);
	},
	hget(hash, key) {
		return redisClient.hget(`${prepend}_${hash}`, key);
	},
	hgetall(hash) {
		return redisClient.hgetall(`${prepend}_${hash}`);
	},
	hdel(hash, key, value) {
		return redisClient.hdel(`${prepend}_${hash}`, key, value);
	}
};
